@@ -145,13 +145,15 @@ arg_check_modified = function(modified) {
 #' @noRd
 arg_check_tobs = function(tobs) {
   if (!is.numeric(tobs)) {
-    stop("tobs should be numeric values")
+    stop("tobs (the vector of observed test statistics) should be numeric values")
   }
   if (!is.vector(tobs)) {
-    stop("tobs should be a vector")
+    stop("tobs (the vector of observed test statistics) should be a vector")
   }
-  if (min(tobs) < 0) {
-    stop("tobs values must be >= 0")
+  # compute minimum observed statistic
+  min_tobs = min(tobs)
+  if (min_tobs < 0) {
+    warning("tobs values (the vector of observed test statistics) should be >= 0. The smallest negative value detected is: ", min_tobs ,". If the smallest negative value is nearly zero, then this is likely a numeric precision issue that can be ignored. If the smallest negative value is not close to zero, then a more serious problem may be present.")
   }
 }
 
