@@ -1,48 +1,48 @@
 #' Dynamic Minimum Spanning Tree spatial scan test
-#' 
-#' \code{dmst.test} implements the dynamic Minimum Spanning Tree
-#' scan test of Assuncao et al. (2006). 
-#' Starting with a single region as a current zone, new 
-#' candidate zones are constructed by combining the current 
-#' zone with the connected region that maximizes the 
-#' resulting likelihood ratio test statistic.  This  
-#' procedure is repeated until the population or distance upper
-#' bounds are reached.  The same procedure is repeated for 
-#' each region.  The clusters returned are non-overlapping, 
-#' ordered from most significant to least significant.  
-#' The first cluster is the most likely to be a cluster.  
-#' If no significant clusters are found, then the most 
-#' likely cluster is returned (along with a warning).
-#' 
-#' The maximum intercentroid distance can be found by 
-#' executing the command: 
-#' \code{sp::spDists(as.matrix(coords), longlat = longlat)}, 
-#' based on the specified values of \code{coords} and 
+#'
+#' \code{dmst.test} implements the dynamic Minimum Spanning
+#' Tree scan test of Assuncao et al. (2006). Starting with a
+#' single region as a current zone, new candidate zones are
+#' constructed by combining the current zone with the
+#' connected region that maximizes the resulting likelihood
+#' ratio test statistic.  This procedure is repeated until
+#' the population or distance upper bounds are reached.  The
+#' same procedure is repeated for each region.  The clusters
+#' returned are non-overlapping, ordered from most
+#' significant to least significant. The first cluster is
+#' the most likely to be a cluster. If no significant
+#' clusters are found, then the most likely cluster is
+#' returned (along with a warning).
+#'
+#' The maximum intercentroid distance can be found by
+#' executing the command:
+#' \code{sp::spDists(as.matrix(coords), longlat = longlat)},
+#' based on the specified values of \code{coords} and
 #' \code{longlat}.
-#' 
+#'
 #' @inheritParams flex.test
 #' @inheritParams scan.test
 #' @param ubd A proportion in (0, 1].  The distance of
-#' potential clusters must be no more than \code{ubd * m}, 
-#' where \code{m} is the maximum intercentroid distance
-#' between all coordinates.
-#' @return Returns a \code{scan} object.
+#'   potential clusters must be no more than \code{ubd * m},
+#'   where \code{m} is the maximum intercentroid distance
+#'   between all coordinates.
+#' @return Returns a \code{smerc_cluster} object.
 #' @author Joshua French
 #' @export
-#' @seealso \code{\link{scan.stat}},
-#'   \code{\link{plot.scan}}, \code{\link{scan.test}},
-#'   \code{\link{flex.test}}, \code{\link{uls.test}},
-#'   \code{\link{bn.test}}
+#' @seealso \code{\link{print.smerc_cluster}},
+#' \code{\link{summary.smerc_cluster}},
+#' \code{\link{plot.smerc_cluster}},
+#' \code{\link{scan.stat}}, \code{\link{scan.test}}
 #' @references Assuncao, R.M., Costa, M.A., Tavares, A. and
 #'   Neto, S.J.F. (2006). Fast detection of arbitrarily
 #'   shaped disease clusters, Statistics in Medicine, 25,
-#'   723-742.  <https://doi.org/10.1002/sim.2411>
-#' @examples 
+#'   723-742.  <doi:10.1002/sim.2411>
+#' @examples
 #' data(nydf)
 #' data(nyw)
 #' coords = with(nydf, cbind(longitude, latitude))
-#' out = dmst.test(coords = coords, cases = floor(nydf$cases), 
-#'                 pop = nydf$pop, w = nyw, 
+#' out = dmst.test(coords = coords, cases = floor(nydf$cases),
+#'                 pop = nydf$pop, w = nyw,
 #'                 alpha = 0.12, longlat = TRUE,
 #'                 nsim = 2, ubpop = 0.05, ubd = 0.1)
 #' data(nypoly)
@@ -110,12 +110,21 @@ dmst.test = function(coords, cases, pop, w,
     warning("No significant clusters.  Returning most likely cluster.")
   }
 
-  # only keep significant clusters
-  zones = zones[sigc]
-  tobs = tobs[sigc]
-  pvalue = pvalue[sigc]
+  # significant, ordered, non-overlapping clusters and
+  # information
+  pruned = sig_noc(tobs = tobs, zones = zones,
+                   pvalue = pvalue, alpha = alpha,
+                   order_by = "tobs")
 
-  prep.scan(tobs = tobs, zones = zones, pvalue = pvalue,
-            coords = coords, cases = cases, pop = pop,
-            ex = ex, longlat = longlat, w = w)
+  smerc_cluster(tobs = pruned$tobs, zones = pruned$zones,
+                pvalue = pruned$pvalue, coords = coords,
+                cases = cases, pop = pop, ex = ex,
+                longlat = longlat, method = "dynamic minimum spanning tree",
+                rel_param = list(type = "poisson",
+                                 simdist = "multinomial",
+                                 nsim = nsim,
+                                 ubpop = ubpop,
+                                 ubd = ubd),
+                alpha = alpha,
+                w = w, d = NULL)
 }
